@@ -53,10 +53,11 @@ class Genome:
     def get_manipulative_map(self):
         return self.manipulative_map
 
-    def change_genes(self, gene_data):
-        ## TODO: find id, gene, and replace value.
+    def change_genes(self, p_id, gene_data):
+        self.agent_genome['primitives'][p_id] = gene_data
         return
 
     def display(self):
         return Cytoscape(data=self.topology, visual_style=self.style_obj, layout={'height': '500px'},
                          background='white')
+
